@@ -3,6 +3,8 @@ from collections.abc import Iterable
 from .mapper_interface import MapperInterface
 import csv
 from typing import Union
+import importlib.resources
+from icdmappings import data_files
 
 class ICD10toICD9(MapperInterface):
     """
@@ -11,30 +13,17 @@ class ICD10toICD9(MapperInterface):
     Source of mapping: https://www.nber.org/research/data/icd-9-cm-and-icd-10-cm-and-icd-10-pcs-crosswalk-or-general-equivalence-mappings
     """
     def __init__(self):
-        self.path2file = "data_sources/icd10cmtoicd9gem.csv"
+        self.filename = "icd10cmtoicd9gem.csv"
         self._setup()
 
     def _setup(self):
-        filepath = os.path.join(
-            os.path.dirname(
-            os.path.dirname(
-            os.path.dirname(os.path.abspath(__file__)))),
-                self.path2file
-        )
-        
-        self.icd10_to_icd9 = self._parse_file(filepath)
+        self.icd10_to_icd9 = self._parse_file(self.filename)
 
 
     def _map_single(self, icd10code : str):
-            
-        try:
-            return self.icd10_to_icd9[icd10code]
-        except:
-            return None
+        return self.icd10_to_icd9.get(icd10code)
 
-    def map(self,
-            icd10code : Union[str, Iterable]
-            ):
+    def map(self, icd10code : Union[str, Iterable]) -> Union[str, Iterable]:
         """
         Given an icd10 code, returns the corresponding icd9 code.
 
@@ -45,23 +34,23 @@ class ICD10toICD9(MapperInterface):
             icd10 code
 
         Returns:
-            icd9 code or np.nan when the mapping is not possible
+            icd9 code or None when the mapping is not possible
         """
             
         if isinstance(icd10code, str):
             return self._map_single(icd10code)
 
         elif isinstance(icd10code, Iterable):
-            return [ self._map_single(c) for c in icd10code ]
+            return [self._map_single(c) for c in icd10code]
         
-        raise TypeError(f'Wrong input type. Expecting str or pd.Series. Got {type(icd10code)}')    
+        return None
 
 
-    def _parse_file(self, filepath : str):
+    def _parse_file(self, filename : str):
 
         mapping = {}
 
-        with open(filepath) as csvfile:
+        with importlib.resources.open_text(data_files, filename) as csvfile:
             reader = csv.reader(csvfile, quotechar='"')
             headers = next(reader)
 
