@@ -2,8 +2,9 @@ from typing import List, Union
 import os
 from collections.abc import Iterable
 import re
-
 from .mapper_interface import MapperInterface
+import importlib.resources
+from icdmappings import data_files
 
 class ICD9toCCS(MapperInterface):
         """
@@ -12,42 +13,29 @@ class ICD9toCCS(MapperInterface):
         source of mapping: https://www.hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp
         """
         def __init__(self):
-
-            self.path2file = "data_sources/CCS-SingleDiagnosisGrouper.txt"
+            self.filename = "CCS-SingleDiagnosisGrouper.txt"
             self._setup()
 
 
         def _setup(self):
-            self.path2file = os.path.join(
-                os.path.dirname(
-                os.path.dirname(
-                os.path.dirname(os.path.abspath(__file__)))),
-                  self.path2file
-            )
-             
             # {ccs:[icd9,...],..., ccs:[icd9,...]}
-            self.ccs_to_icd9 = self._parse_file(self.path2file)
+            self.ccs_to_icd9 = self._parse_file(self.filename)
 
             # (inverse mapping): {icd9:ccs,..., icd9:ccs}
             self.icd9_to_ccs = self.ccs_to_icd9 = {self.ccs_to_icd9[ccs][i]:ccs for ccs in self.ccs_to_icd9 for i in range(len(self.ccs_to_icd9[ccs]))} 
         
-        def _parse_file(self, filepath : str):
-            with open(filepath,"r") as f:
+        def _parse_file(self, filename : str):
+            with importlib.resources.open_text(data_files, filename) as f:
                 content = f.read()
             return self._get_codes(content)
         
-        def _map_single(self, icd9code : str):
-            try:
-                return self.icd9_to_ccs[icd9code]
-            except:
-                return None
+        def _map_single(self, icd9code : str) -> str:
+            return self.icd9_to_ccs.get(icd9code)
 
-        def map(self,
-                icd9code: Union[str, Iterable]
-                ):
+        def map(self,icd9code: Union[str, Iterable]) -> Union[str, Iterable]:
             """
-            Given an icd9 code, returns the corresponding ccs code.
-            If input is Iterable returns a list of codes. If np.array or pd.Series, returns in the same format.
+            Given an icd9 code, returns the corresponding CCS code.
+            If input is Iterable returns a list of codes. 
             
             Parameters
             ----------
@@ -56,8 +44,7 @@ class ICD9toCCS(MapperInterface):
                 icd9 code
             
             Returns:
-              None: code doesn't match
-              >0: corresponding ccs code
+                ccs code or None when the mapping is not possible
             """
             
             if isinstance(icd9code, str):
@@ -65,7 +52,8 @@ class ICD9toCCS(MapperInterface):
             
             elif isinstance(icd9code, Iterable):
                 return[self._map_single(code) for code in icd9code]
-            raise TypeError('Expects a string or iterable of strings as codes.')
+            
+            return None
 
         def _get_codes(self, content : str):
             """
