@@ -4,6 +4,8 @@ from collections.abc import Iterable
 from .mapper_interface import MapperInterface
 import bisect
 import csv
+import importlib.resources
+from icdmappings import data_files
 
 class ICD9toChapters(MapperInterface):
         """
@@ -12,29 +14,36 @@ class ICD9toChapters(MapperInterface):
         source of mapping: https://icd.codes/icd9cm
         """
         def __init__(self):
-            self.path2file = "data_sources/icd9-CM-code-chapter-en=PT.csv"
+            self.filename = "icd9-CM-code-chapter-en=PT.csv"
             self._setup()
 
         def _setup(self):
-            filepath = os.path.join(
-                os.path.dirname(
-                os.path.dirname(
-                os.path.dirname(os.path.abspath(__file__)))),
-                  self.path2file
-            )
-
-            # creates self.chapters_num, self.chapters_char, self.bins
-            self.bins, self.char_mapping = self._parse_file(filepath)
-
+            self.bins, self.char_mapping = self._parse_file(self.filename)
         
-        def _map_single(self,icd9code : str):
+        def _map_single(self, icd9code : str) -> str:
+            """
+            Maps a single ICD9 code in string format to its corresponding chapter.
 
-            if not isinstance(icd9code,str):
+            Parameters
+            ----------
+            icd9code : str
+                ICD9 code to be mapped.
+
+            Returns
+            -------
+            chapter : str
+                Corresponding icd9 chapter or None if mapping is unsuccessful.
+            """
+
+            if not icd9code: # empty string or None
                 return None
 
+            if not isinstance(icd9code, str): # has to be string
+                return None
+            
             if icd9code[0] in ['E','V']:
                 return self.char_mapping[icd9code[0]]
-            else:
+            else: # numerical code
                 try:
                     code3digits = int(icd9code[:3])
                     bin = self._get_bin(code3digits,self.bins)
@@ -45,8 +54,10 @@ class ICD9toChapters(MapperInterface):
                     return None
 
 
-        def map(self, icd9code : Union[str, Iterable]):
+        def map(self, icd9code : Union[str, Iterable]) -> Union[str, Iterable]:
             """
+            Maps an ICD9 code or an Iterable of ICD9 codes to their corresponding chapters.
+
             Parameters
             ----------
             code : str | Iterable
@@ -54,14 +65,13 @@ class ICD9toChapters(MapperInterface):
             Returns
             -------
             chapter : str | Iterable
-                Corresponding icd9 chapter or None if mapping is unsuccessful.
+                Corresponding icd9 chapter(s) or None when mapping is unsuccessful.
             """
             if isinstance(icd9code,str):
                 return self._map_single(icd9code)
+            
             elif isinstance(icd9code, Iterable):
                 return [self._map_single(code) for code in icd9code]
-            raise TypeError(f'Wrong input type. Expecting str or Iterable. Got {type(icd9code)}')
-                    
 
         def _get_bin(self, number : Union[int, Iterable], bins : List):
             if isinstance(number,int):
@@ -71,14 +81,14 @@ class ICD9toChapters(MapperInterface):
             return None
             
 
-        def _parse_file(self,filepath : str):
+        def _parse_file(self, filename : str):
             """
-            Some preprocessing to optimize assignment speed later using np.digitize
+            Preprocessing of bins to optimize assignment speed during mapping.
             1. Separate chapters into numeric codes or alpha codes (There are two chapters considered alpha because they start with "E" or "V")
             2. Create self.bins, which contains starting code ranges of each chapter
             """
 
-            with open(filepath) as csvfile:
+            with importlib.resources.open_text(data_files, filename) as csvfile:
                 reader = csv.reader(csvfile, quotechar="'")
                 headers = next(reader)
 
