@@ -3,31 +3,28 @@ from collections.abc import Iterable
 from .mapper_interface import MapperInterface
 import csv
 from typing import Union
+import importlib.resources
+from icdmappings import data_files
 
 
 class ICD9toICD10(MapperInterface):
     """
     Maps icd9 codes into icd10.
     
-    
     Source of mapping: https://www.nber.org/research/data/icd-9-cm-and-icd-10-cm-and-icd-10-pcs-crosswalk-or-general-equivalence-mappings
     """
     def __init__(self):
-        self.path2file = "data_sources/icd9toicd10cmgem.csv"
+        self.filename = "icd9toicd10cmgem.csv"
         self._setup()
 
     def _setup(self):
-        filepath = os.path.join(
-            os.path.dirname(
-            os.path.dirname(
-            os.path.dirname(os.path.abspath(__file__)))),
-                self.path2file
-        )
+        self.icd9_to_icd10 = self._parse_file(self.filename)
 
-        # creates self.chapters_num, self.chapters_char, self.bins
-        self.icd9_to_icd10 = self._parse_file(filepath)
+    def _map_single(self, icd9code : str):
+            
+        return self.icd9_to_icd10.get(icd9code)
 
-    def map(self,icd9code : Union[str, Iterable]):
+    def map(self, icd9code : Union[str, Iterable]) -> Union[str, Iterable]:
             """
             Given an icd9 code, returns the corresponding icd10 code.
 
@@ -40,25 +37,18 @@ class ICD9toICD10(MapperInterface):
             Returns:
                 icd10 code or None when the mapping is not possible
             """
-            def map_single(code : str):
-                try:
-                    return self.icd9_to_icd10[code]
-                except:
-                    return None
             
             if isinstance(icd9code, str):
-                return  map_single(icd9code)
-            elif isinstance(icd9code, Iterable):
-                return [ map_single(c) for c in icd9code ]
+                return  self._map_single(icd9code)
             
-            raise TypeError(f'Wrong input type. Expecting str or Iterable. Got {type(icd9code)}')
+            elif isinstance(icd9code, Iterable):
+                return [self._map_single(c) for c in icd9code]
 
-
-    def _parse_file(self, filepath : str):
+    def _parse_file(self, filename : str):
 
         mapping = {}
 
-        with open(filepath) as csvfile:
+        with importlib.resources.open_text(data_files, filename) as csvfile:
             reader = csv.reader(csvfile, quotechar='"')
             headers = next(reader)
 
